accelEE-package: accelEE: Predict Energy Expenditure from Accelerometer Data

accelEE-packageR Documentation

accelEE: Predict Energy Expenditure from Accelerometer Data

Description

This is a package to simplify and integrate the application of various energy expenditure models. It is a simple purpose but a powerful tool. As models proliferate (often in other packages), they can be added into this package's framework and ecosystem, making accelEE a hub for many spokes. By providing a centralized location for these resources and a single, unified framework (with consistent syntax etc.) the package enables seamless and flexible use of different methods.

Details

The core function is accelEE, and the documentation page has extensive detail on what options and capabilities are available. Start there and post an issue on GitHub if you need additional clarity, find a bug, or wish to suggest a new feature.

Author(s)

Maintainer: Paul R. Hibbing paulhibbing@gmail.com

Other contributors:

  • Children's Mercy Kansas City [copyright holder]

See Also

Useful links:


accelEE documentation built on Aug. 29, 2026, 1:07 a.m.