ee_file: Run a pre-specified processing scheme

View source: R/ee_file__main.R

ee_fileR Documentation

Run a pre-specified processing scheme

Description

Pre-specified routines are designed to facilitate replication of methods from prior studies

Usage

ee_file(filename, scheme = "Hibbing 2023", ...)

Arguments

filename

character. Path to the file

scheme

character. Name of the routine to be executed. Currently the only option is "Hibbing 2023".

...

Arguments passed to sub-routine functions

Value

A data frame whose contents are prepared according to the indicated scheme

See Also

hibbing23-file

Examples

  f <- system.file("extdata/TAS1H30182785_2019-09-17.gt3x", package = "read.gt3x")
  ee_file(f)

accelEE documentation built on Aug. 29, 2026, 1:07 a.m.