ee_summary: Run a pre-specified summary scheme

View source: R/ee_summary__main.R

ee_summaryR Documentation

Run a pre-specified summary scheme

Description

Pre-specified routines are designed to facilitate replication of methods from prior studies

Usage

ee_summary(d, scheme = "Hibbing 2023", ...)

Arguments

d

input data (presumably a data frame)

scheme

character. Name of the routine to be executed. Currently the only option is "Hibbing 2023".

...

Arguments passed to sub-routine functions

Value

A data frame whose contents are prepared according to the indicated scheme

See Also

Subroutine function(s): hibbing23-summary

Examples


f <- system.file("extdata/TAS1H30182785_2019-09-17.gt3x", package = "read.gt3x")

## Read acceleration data
  accel <- ee_file(f)

## Generate some bogus count data
  cts <- data.frame(
    Timestamp = accel$Timestamp,
    Axis1 = 0, Axis2 = 0, Axis3 = 0,
    valid_status = "Non-Wear"
  )

## Returns NA with a warning about no complete days in the file
  suppressWarnings(ee_summary(
    merge(accel, cts)
  ))


accelEE documentation built on Aug. 29, 2026, 1:07 a.m.