hibbing23-file: Run the Hibbing 2023 file preparation routine

hibbing23-fileR Documentation

Run the Hibbing 2023 file preparation routine

Description

Run the Hibbing 2023 file preparation routine

Usage

## Wrapper function:
ee_file_hibbing23(filename, ...)


## Sub-routine functions
agd_hibbing23(filename, verbose = FALSE, ...)

Arguments

filename

character. Path to the file

...

Arguments passed to sub-routine functions

verbose

logical. Print updates to console?

Value

A data frame whose contents are prepared according to the Hibbing 2023 scheme

Note

This routine requires the PhysicalActivity, PhysActBedRest, and read.gt3x packages. Also note that the original Hibbing paper used a package called AGread rather than read.gt3x, and there are some differences. AGread is available on GitHub, but not CRAN–hence, the requirement for read.gt3x here.


accelEE documentation built on Aug. 29, 2026, 1:07 a.m.