hibbing23-summary: Run the Hibbing 2023 summary scheme

hibbing23-summaryR Documentation

Run the Hibbing 2023 summary scheme

Description

Run the Hibbing 2023 summary scheme

Usage

ee_summary_hibbing23(d, verbose = FALSE)

Arguments

d

input data (presumably a data frame)

verbose

logical. Print updates to console?

Value

A data frame whose contents are prepared according to the indicated scheme

Examples


f <- system.file("extdata/TAS1H30182785_2019-09-17.gt3x", package = "read.gt3x")

## Read acceleration data
  accel <- ee_file(f)

## Generate some bogus count data
  cts <- data.frame(
    Timestamp = accel$Timestamp,
    Axis1 = 0, Axis2 = 0, Axis3 = 0,
    valid_status = "Non-Wear"
  )

## Returns NA with a warning about no complete days in the file
  suppressWarnings(ee_summary(
    merge(accel, cts)
  ))


accelEE documentation built on Aug. 29, 2026, 1:07 a.m.