View source: R/ee_file__main.R
| ee_file | R Documentation |
Pre-specified routines are designed to facilitate replication of methods from prior studies
ee_file(filename, scheme = "Hibbing 2023", ...)
filename |
character. Path to the file |
scheme |
character. Name of the routine to be executed. Currently the
only option is |
... |
Arguments passed to sub-routine functions |
A data frame whose contents are prepared according to the indicated scheme
hibbing23-file
f <- system.file("extdata/TAS1H30182785_2019-09-17.gt3x", package = "read.gt3x")
ee_file(f)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.