| hibbing23-summary | R Documentation |
Run the Hibbing 2023 summary scheme
ee_summary_hibbing23(d, verbose = FALSE)
d |
input data (presumably a data frame) |
verbose |
logical. Print updates to console? |
A data frame whose contents are prepared according to the indicated scheme
f <- system.file("extdata/TAS1H30182785_2019-09-17.gt3x", package = "read.gt3x")
## Read acceleration data
accel <- ee_file(f)
## Generate some bogus count data
cts <- data.frame(
Timestamp = accel$Timestamp,
Axis1 = 0, Axis2 = 0, Axis3 = 0,
valid_status = "Non-Wear"
)
## Returns NA with a warning about no complete days in the file
suppressWarnings(ee_summary(
merge(accel, cts)
))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.