| montoye_features | R Documentation |
Calculate features for Montoye's neural networks
montoye_features(
d,
time_var = "Timestamp",
x_var = "Accelerometer_X",
y_var = "Accelerometer_Y",
z_var = "Accelerometer_Z",
side = c("left", "right"),
win_width_sec = 30,
verbose = FALSE,
...
)
d |
data frame of data to use for generating predictions |
time_var |
character. Name of the column containing POSIX-formatted timestamps |
x_var |
character. Name of the X-axis variable |
y_var |
character. Name of the Y-axis variable |
z_var |
character. Name of the Z-axis variable |
side |
character vector or scalar indicating which side-specific wrist
model(s) to implement for |
win_width_sec |
desired window width for features |
verbose |
logical. Print updates to console? |
... |
currently unused |
A dataframe of features for entry into the neural networks
Montoye et al. (2017) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/1091367X.2017.1337638")}
if (isTRUE(requireNamespace("read.gt3x"))) {
f <- system.file("extdata/TAS1H30182785_2019-09-17.gt3x", package = "read.gt3x")
d <- read.gt3x::read.gt3x(f, asDataFrame = TRUE, imputeZeroes = TRUE)
montoye_features(d[1:12000, ], "time", "X", "Y","Z", "right")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.